@@ -1,5 +1,5 @@
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Makefile.pm $ $Author: autrijus $
-# $Revision: #4 $ $Change: 1397 $ $DateTime: 2003/03/23 21:44:22 $ vim: expandtab shiftwidth=4
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Makefile.pm $ $Author: ingy $
+# $Revision: #5 $ $Change: 1474 $ $DateTime: 2003/05/05 15:25:47 $ vim: expandtab shiftwidth=4
 
 package Module::Install::Admin::Makefile;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -25,7 +25,7 @@ realclean purge ::
 
 reset :: purge
 \t\$(RM_RF) inc MANIFEST.bak _build
-\t\$(PERL) -M$admin_class -e \"remove_meta()\"
+\t\$(PERL) -I. -M$admin_class -e \"remove_meta()\"
 
 upload :: test dist
 \tcpan-upload -verbose \$(DISTVNAME).tar\$(SUFFIX)
@@ -44,7 +44,7 @@ END
 sub preop {
     my $self = shift;
     my $admin_class = join('::', @{$self->_top}{qw(name dispatch)});
-    +{ PREOP => qq{\$(PERL) -M$admin_class -e "dist_preop()"} }
+    +{ PREOP => qq{\$(PERL) -I. -M$admin_class -e "dist_preop()"} }
 }
 
 1;
